/* 
 Ce programme permet a l'utilisateur d'ajuster la lumiere d'une led RGB.
 */

//------------------------------------------------------------
// Librairies
//------------------------------------------------------------

// pour le traitement du message recu sur la liaison serie
#include <SerialDLF.h>

//------------------------------------------------------------
// Constantes
//------------------------------------------------------------

// Classe de SerialDLF
SerialString messageRecu;

const int pinRouge = 11 ;
const int pinVert = 10 ;
const int pinBleu = 9 ;

int niveauRougeInitial =128;
int niveauVertInitial =128;
int niveauBleuInitial =128;


const int indiceRouge=0;
const int indiceVert=1;
const int indiceBleu=2;

int tableauCouleurs[3]={
  pinRouge,pinVert,pinBleu};
int tableauNiveaux[3]={
  niveauRougeInitial,niveauVertInitial,niveauBleuInitial};

int indiceCourant=indiceRouge;

//------------------------------------------------------------
// Setup
//------------------------------------------------------------

void setup()
{
  // Initialisation de la liaison serie
  Serial.begin(9600); 
  Serial.flush();
  Serial.println("Liaison serie operationnelle !");
  Serial.println("------------------------------");
  delay(1000);
  Serial.println("Descriptif du programme :");
  Serial.println("--------------------------");
  Serial.println("Ce programme permet a l'utilisateur d'ajuster la couleur d'une led RGB.");
  Serial.println("--------------------------");
  Serial.println("Pour connaitre les commandes, taper sur h ou H.");
  Serial.println("--------------------------");


  // Autres initilisations


  pinMode(pinRouge, OUTPUT );
  pinMode(pinVert, OUTPUT );
  pinMode(pinBleu, OUTPUT );



  analogWrite(pinRouge,niveauRougeInitial);
  analogWrite(pinVert,niveauVertInitial);
  analogWrite(pinBleu,niveauBleuInitial);



} // fin setup

//------------------------------------------------------------
// Loop
//------------------------------------------------------------

void loop()
{ 
  messageRecu.renew();  // on lit un eventuel message.
  if (messageRecu.empty()==false) // Si le message est non vide ...
  {
    //Serial.println(messageRecu.get());
    traitement();
    Serial.flush();
  }
} //fin loop

//------------------------------------------------------------
// Fonction traitement()
//------------------------------------------------------------
/*
Execute le traitement des caracteres recus par la liaison serie
 qui sont stockes dans messageRecu.
 */

void traitement()
{
  int niveau;

  if ((messageRecu.equals("Descriptif")) || (messageRecu.equals("d")))
  {
    Serial.println("--------------------------");
    Serial.println("Descriptif du programme :");
    Serial.println("--------------------------");
    Serial.println("Ce programme permet d'ajuster la couleur d'une led RGB.");
    Serial.println("--------------------------");
  }    
  else   if ((messageRecu.equals("Help")) || (messageRecu.equals("h")))
  {
    Serial.println("--------------------------");
    Serial.println("Liste des commandes :");
    Serial.println("--------------------------");
    Serial.println("--> Descriptif ou d : affiche le descriptif du programme.");
    Serial.println("--> Help ou h : affiche la liste des commandes.");
    Serial.println("--> Red ou r : la couleur a modifier est le rouge.");
    Serial.println("                On peut passer en parametres le niveau.");
    Serial.println("                Exemple : r 255");
    Serial.println("--> Green ou g : la couleur a modifier est le vert.");
    Serial.println("                On peut passer en parametres le niveau.");
    Serial.println("                Exemple : g 128");
    Serial.println("--> Blue ou b : la couleur a modifier est le bleu.");
    Serial.println("                On peut passer en parametres le niveau.");
    Serial.println("                Exemple : b 0");
    Serial.println("--> Plus ou + : augmente de 1 le niveau de la couleur courante (le rouge par defaut).");
    Serial.println("--> Moins ou - : diminue de 1 le niveau de la couleur courante (le rouge par defaut).");
    Serial.println("--> Zero ou z : met le niveau de la couleur courante a 0 (le rouge par defaut).");
    Serial.println("--> Maximum ou m : met le niveau de la couleur courante a 255 (le rouge par defaut).");
    Serial.println("--> Afficher ou a : affiche les niveaux des 3 couleurs.");
    Serial.println("--------------------------");
  }

  else   if ((messageRecu.equals("Red")) || (messageRecu.equals("r")) || (messageRecu.equals("Rouge")))
  {
    Serial.println("Couleur active : le rouge.");
    indiceCourant=indiceRouge;
    if (messageRecu.withParameter()==true)
    {
      niveau=messageRecu.parameter();
      ;
      niveau=constrain(niveau,0,255);
      tableauNiveaux[indiceCourant]=niveau;
      analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
    }
  }
  else if ((messageRecu.equals("Green")) || (messageRecu.equals("g")) || (messageRecu.equals("Vert")) || (messageRecu.equals("v")))
  {
    Serial.println("Couleur active : le vert.");
    indiceCourant=indiceVert;
    if (messageRecu.withParameter()==true)
    {
      niveau=messageRecu.parameter();
      ;
      niveau=constrain(niveau,0,255);
      niveau=constrain(niveau,0,255);
      tableauNiveaux[indiceCourant]=niveau;
      analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
    }
  }

  else if ((messageRecu.equals("Blue")) || (messageRecu.equals("b")) || (messageRecu.equals("Blue")) )
  {
    Serial.println("Couleur active : le bleu.");
    indiceCourant=indiceBleu;
    if (messageRecu.withParameter()==true)
    {
      niveau=messageRecu.parameter();
      ;
      niveau=constrain(niveau,0,255);
      niveau=constrain(niveau,0,255);
      tableauNiveaux[indiceCourant]=niveau;
      analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
    }
  }

  else if ((messageRecu.equals("Plus")) || (messageRecu.equals("+")) )
  {
    if (tableauNiveaux[indiceCourant] <255)
    {
      tableauNiveaux[indiceCourant]=tableauNiveaux[indiceCourant]+1;
    }
    else
    {
      Serial.println("Niveau maximum atteint : 255."); 
    }
    analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
  }
  else if ((messageRecu.equals("Moins")) || (messageRecu.equals("-")) )
  {
    if (tableauNiveaux[indiceCourant] >0)
    {
      tableauNiveaux[indiceCourant]=tableauNiveaux[indiceCourant]-1;
    }
    else
    {
      Serial.println("Niveau minimum atteint : 0."); 
    }
    analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
  }

  else if ((messageRecu.equals("Zero")) || (messageRecu.equals("z")) || (messageRecu.equals("Minimum")) || (messageRecu.equals("Min")) )
  {
    tableauNiveaux[indiceCourant]=0;
    analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
  }

  else if ((messageRecu.equals("Maximum")) || (messageRecu.equals("m")) || (messageRecu.equals("Max")))
  {
    tableauNiveaux[indiceCourant]=255;
    analogWrite(tableauCouleurs[indiceCourant],tableauNiveaux[indiceCourant]);
  }   

  else if ((messageRecu.equals("Afficher")) || (messageRecu.equals("a")) )
  {
    Serial.print("R " + String(tableauNiveaux[indiceRouge]));
    Serial.print("    G " + String(tableauNiveaux[indiceVert]));
    Serial.println("    B " + String(tableauNiveaux[indiceBleu]));
  }

  else
  {
    Serial.println("Erreur de saisie !");
  }


} // fin traitement






