/*
  SensoduinoDLF.cpp - Arduino Library
  Copyright (c) 2013 Denis LE FUR.  All right reserved.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "Arduino.h"
#include "SensoduinoDLF.h"

//-------------------------------------------------
// Classe Sensoduino
//------------------------------------------------- 
Sensoduino::Sensoduino(String message)
{
	String part;
	int index_i=0;
	int index_f;
	message=message.substring(1); // get off '>'
	// analyses the type
	index_f=message.indexOf(',');
	part=message.substring(index_i,index_f);
	_type=part.toInt();
	
	// analyses the counter
	index_i=index_f+1;
	message=message.substring(index_i); // get off '>'
	index_f=message.indexOf(',');
	part=message.substring(0,index_f);
	_counter=part.toInt();	
	
	// analyses the val0
	index_i=index_f+1;
	message=message.substring(index_i);
	index_f=message.indexOf(',');
	part=message.substring(0,index_f);
	char floatbuf0[32];
	part.toCharArray(floatbuf0, sizeof(floatbuf0));
	_val0 = atof(floatbuf0);
	
	// analyses the val1
	index_i=index_f+1;
	message=message.substring(index_i);
	index_f=message.indexOf(',');
	part=message.substring(0,index_f);
	char floatbuf1[32];
	part.toCharArray(floatbuf1, sizeof(floatbuf1));
	_val1 = atof(floatbuf1);
	
	// analyses the val2
	index_i=index_f+1;
	part=message.substring(index_i);
	char floatbuf2[32];
	part.toCharArray(floatbuf2, sizeof(floatbuf2));
	_val2 = atof(floatbuf2);
}


//-------------------------------------------------
// get()
//------------------------------------------------- 
/*
returns the parameters.
*/
String Sensoduino::get()
{
	String affichage ;
	char tabval0[32];
	dtostrf(_val0,1,10,tabval0);
	char tabval1[32];
	dtostrf(_val1,1,10,tabval1);
	char tabval2[32];
	dtostrf(_val2,1,10,tabval2);
	
	if (_type==SSD_TIME)
	{
		affichage="TIME : \n";
		affichage = affichage + String((int) _val0) + " H ";
		affichage = affichage + String((int) _val1) + " m ";
		affichage = affichage + String((int) _val2) + " s\n";
				
	}
	else if (_type==SSD_DATE)
	{
		affichage="DATE : \n";
		affichage = affichage + String((int) _val2) + " / ";
		affichage = affichage + String((int) _val1) + " / ";
		affichage = affichage + String((int) _val0) + " \n";
		
	}
	else if (_type==SSD_AUDIO)
	{
		affichage="AUDIO : \n";
		affichage = affichage + "Volume : " + String((int) _val0) + " \n";
				
	}
	else if (_type==SSD_PROXIMITY)
	{
		affichage="PROXIMITY : \n";
		if (_val0==0.0)
		{
			affichage = affichage + "Obstacle en vue \n";
		}
		else
		{
			affichage = affichage + "Pas d'obstacle \n";
		}		
	}
	if (_type==SSD_ACCELEROMETER)
	{
		affichage="ACCELEROMETER : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_MAGNETIC_FIELD)
	{
		affichage="MAGNETIC_FIELD : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_GYROSCOPE)
	{
		affichage="GYROSCOPE : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_ACCELERATION)
	{
		affichage="LINEAR_ACCELERATION : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_ROTATION)
	{
		affichage="ROTATION_VECTOR : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_MAGNETIC_FIELD_UNCALIBRATED)
	{
		affichage="MAGNETIC_FIELD_UNCALIBRATED : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_GAME_ROTATION_VECTOR)
	{
		affichage="GAME_ROTATION_VECTOR : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_GYROSCOPE_UNCALIBRATED)
	{
		affichage="GYROSCOPE_UNCALIBRATED : \n";
		affichage = affichage + "X : " + tabval0 + " \n";
		affichage = affichage + "Y : " + tabval1 + " \n";
		affichage = affichage + "Z : " + tabval2 + " \n";
				
	}
	if (_type==SSD_ORIENTATION)
	{
		affichage="ORIENTATION : \n";
		affichage = affichage + "Yaw : " + tabval0 + " \n";
		affichage = affichage + "Pitch : " + tabval1 + " \n";
		affichage = affichage + "Roll : " + tabval2 + " \n";
				
	}
	if (_type==SSD_GPS1)
	{
		affichage="GPS1 : \n";
		affichage = affichage + "Latitude : " + tabval0 + " \n";
		affichage = affichage + "Longitude : " + tabval1 + " \n";
		affichage = affichage + "Altitude : " + tabval2 + " \n";
				
	}
	if (_type==SSD_GPS2)
	{
		affichage="GPS1 : \n";
		affichage = affichage + "Bearing : " + tabval0 + " \n";
		affichage = affichage + "Speed : " + tabval1 + " \n";
		affichage = affichage + "Date/time : " + tabval2 + " \n";
				
	}
	if (_type==SSD_LIGHT)
	{
		affichage="LIGHT : \n";
		affichage = affichage + "Light : " + tabval0 + " \n";
				
	}
	if (_type==SSD_PRESSURE)
	{
		affichage="PRESSURE : \n";
		affichage = affichage + "Pressure : " + tabval0 + " \n";
				
	}
	if (_type==SSD_DEVICE_TEMPERATURE)
	{
		affichage="DEVICE TEMPERATURE : \n";
		affichage = affichage + "Device Temperature : " + tabval0 + " \n";
				
	}
	if (_type==SSD_AMBIENT_TEMPERATURE)
	{
		affichage="AMBIENT TEMPERATURE : \n";
		affichage = affichage + "Ambient Temperature : " + tabval0 + " \n";
				
	}
	if (_type==SSD_RELATIVE_HUMIDITY)
	{
		affichage="RELATIVE HUMIDITY : \n";
		affichage = affichage + "Pourcentage : " + tabval0 + " \n";
				
	}
	
	else
	{
		affichage = "Type : " +String(_type) + "  Counter : "+ String (_counter);
		affichage = affichage + "  val0 : " + tabval0 + "  val1 : " + tabval1;
		affichage = affichage + "  val2 : " + tabval2;
		
	}
	return affichage;
}

//-------------------------------------------------
// getType()
//------------------------------------------------- 
/*
returns the type.
*/
int Sensoduino::getType()
{
	return _type;
}

//-------------------------------------------------
// getCounter()
//------------------------------------------------- 
/*
returns the counter.
*/
int Sensoduino::getCounter()
{
	return _counter;
}

//-------------------------------------------------
// getVal0()
//------------------------------------------------- 
/*
returns the val0.
*/
float Sensoduino::getVal0()
{
	return _val0;
}

//-------------------------------------------------
// getVal1()
//------------------------------------------------- 
/*
returns the val1.
*/
float Sensoduino::getVal1()
{
	return _val1;
}

//-------------------------------------------------
// getVal2()
//------------------------------------------------- 
/*
returns the val2.
*/
float Sensoduino::getVal2()
{
	return _val2;
}



